Description: 
RandSelector class in the rand_selector module contains a function select_rand,
that can select a random a value from the data set and its associated probability


pip installattion:
give command:
	 'pip install randSelector' 

import using:
	 'from  randSelector.rand_selector  import RandSelecter'

run command:
	RandSelecter.select_rand( ((1, 0.6), (3, 0.4))), seed_num=10)	 

